import { Todo } from "@src/core/entities/todo";
import { TodoItem } from "@src/components/todos/todoItem";
import { AddTodo } from "@src/components/todos/addTodo";
import { useUpdateTodo } from "@src/presentation/hooks/socketHooks";
import { useMemo, useState } from "react";

export const TodoList = (props: {
  todos: Todo[];
  hideDone: boolean;
  hideProject: boolean;
  project: string;
  folded: boolean;
}) => {
  const { updateTodo } = useUpdateTodo();

  const todos: Todo[] = useMemo(() => {
    return props.todos
      .filter((t) => {
        if (!props.hideDone) return true;

        return t.status == false;
      })
      .sort((a, b) => a.created - b.created)
      .sort((a, b) => b.priority?.localeCompare(a.priority));
  }, [props.todos, props.hideDone]);

  return (
    <>
      {props.folded && <div>...</div>}
      <div className={`space-y-2 ${props.folded ? "hidden" : "block"}`}>
        <ul id="inbox">
          {todos.map((t, i) => (
            <li key={i}>
              <TodoItem
                todo={t}
                updateTodo={(todo) => {
                  updateTodo(todo);
                }}
                displayProject={!props.hideProject}
              />
            </li>
          ))}
        </ul>
        <AddTodo project={props.project} />
      </div>
    </>
  );
};
